clear all

%% SYSTEM PARAMETER

SP.Case = 10;                                         % # of evaluated cases
SP.Nr = 128;                                         % # of Rx antennas
SP.Nu = 8;                                           % # of users
SP.Nrf = ceil(SP.Nr/3);                              % # of RF chains
SP.p_dB = linspace(-10,15,SP.Case);                  % Tx SNR in dB
SP.p = 10.^(SP.p_dB/10);
SP.b = 3;                                            % # of quantization bits
SP.L = 3;                                            % # of avergae channel paths                                    % Rayleigh channel or not (1: Rayleigh 0: mmWave)
SP.BBcombiner = 'zf';                                % mrc / zf / mmse                                 % Stopping criterion for alternating projection
SP.ARV_size = SP.Nr;                                 % ARV codebook size
SP.itermax = 100;                                     % Maximum # of iterations


%% SIMULATOR

Case = SP.Case;
R_SVD = zeros(Case,1);
R_SVD_DFT = zeros(Case,1);
R_ARV = zeros(Case,1);
R_ARV_DFT = zeros(Case,1);
R_greedy = zeros(Case,1);
R_greedy_DFT = zeros(Case,1);
for n = 1:Case
    tic
    
    [n, SP.p(n)]
    R = Simulator(SP, n);
    
    R_SVD(n) = R.SVD; % One-stage with SVD
    R_SVD_DFT(n) = R.SVD_DFT; % Two-stage with SVD + DFT
    R_ARV(n) = R.ARV; % One-stage with ARV
    R_ARV_DFT(n) = R.ARV_DFT; % Two-stage with ARV + DFT
    R_greedy(n) = R.greedy; % One-stage
    R_greedy_DFT(n) = R.greedy_DFT; % Two-stage with greedy + DFT
     
    R
    toc
end


%% PLOTS

n = SP.p_dB;
% n = SP.b;

figure
plot(n, R_SVD_DFT,'k-', n, R_ARV_DFT,'r-v',n, R_greedy_DFT,'r-s',n, R_greedy,'b-x',n, R_ARV,'b-o', n, R_SVD,'g-s')
grid on
legend('SVD-DFT','ARV-TSAC (proposed)','Greedy-TSAC (proposed)','Greedy-MI','ARV','SVD','Interpreter','latex')
ylabel('Ergodic Sum Rate $\bar\mathcal{R}$ [bps/Hz]','Interpreter','latex')
xlabel('Cases','Interpreter','latex')


