function [R] = Simulator(SP, n)
%% Varing parameter

SP.p = SP.p(n);
% SP.b = SP.b(n);


%% Parameters

Nr = SP.Nr;
Nrf = SP.Nrf;
Nu = SP.Nu;
L = SP.L;
b = SP.b;
itermax = SP.itermax;

% Codebook Generator
A_codebook = [];
theta=-1:2/Nr:1-2/Nr;
for i=1:Nr
    A_codebook = [A_codebook, SteeringGen(theta(i),Nr)];
end

% Quantization gain
bTable = [0.3634, 0.1175, 0.03454, 0.009497, 0.002499];
if b > 5
    a = (1 - pi*sqrt(3)/2*2.^(-2*b));
else
    a = (1 - bTable(floor(b)));
end

%% Iteration

R_SVD = zeros(itermax, 1);
R_SVD_DFT = zeros(itermax, 1);
R_ARV = zeros(itermax, 1);
R_ARV_DFT = zeros(itermax, 1);
R_greedy = zeros(itermax, 1);
R_greedy_DFT = zeros(itermax, 1);
for i = 1:itermax
    
    % Channel Generation
    H = zeros(Nr, Nu);
    for u = 1:Nu
        UE(u).L = max(1, poissrnd(L));
        UE(u).g = 1/sqrt(2)*(randn(UE(u).L,1) + 1j*randn(UE(u).L,1)); % Complex Path Gains
        UE(u).theta = 2.*rand(UE(u).L,1); % Spatial Angle-of-Arrivals
        A = SteeringGen(UE(u).theta, Nr); % Array Steering Vectors
        H(:,u) = sqrt(Nr/UE(u).L)*A*UE(u).g;
    end
    
    
    % Analog Combiner
    Wdft = 1/sqrt(Nrf)*dftmtx(Nrf); % Second Analog Combiner
    
    [U, ~, ~] = svd(H);
    U1 = U(:,1:Nrf);
    Warv = ARV_max(SP, H, A_codebook);
    Wgrdy = greedy_MI(SP,H, A_codebook,a);
    
    % Achievable Sum Rate
    R_SVD(i) = Rate_AQNM(SP, H, U1(:,1:Nrf), a);
    R_SVD_DFT(i) = Rate_AQNM(SP, H, U1*Wdft, a);
    R_ARV(i) = Rate_AQNM(SP, H, Warv, a);
    R_ARV_DFT(i) = Rate_AQNM(SP, H, Warv*Wdft, a); % ARV-TSAC
    R_greedy(i) = Rate_AQNM(SP, H, Wgrdy, a);
    R_greedy_DFT(i) = Rate_AQNM(SP, H, Wgrdy*Wdft, a); % Greedy-DFT
 
end

% Average
R.SVD = abs(mean(R_SVD));
R.SVD_DFT = abs(mean(R_SVD_DFT));
R.ARV = abs(mean(R_ARV));
R.ARV_DFT = abs(mean(R_ARV_DFT));
R.greedy = abs(mean(R_greedy));
R.SVD_upper = Nu*log2(1+a/(1-a));
R.greedy_DFT = abs(mean(R_greedy_DFT));
end

